diff test/runtime/NMT/CommandLineDetail.java @ 15280:417e2ae45b89

Merge
author Michael Van De Vanter <michael.van.de.vanter@oracle.com>
date Tue, 22 Apr 2014 18:22:40 -0700
parents 4ca6dc0799b6
children 52b4284cb496
line wrap: on
line diff
--- a/test/runtime/NMT/CommandLineDetail.java	Sun Apr 20 20:37:27 2014 -0700
+++ b/test/runtime/NMT/CommandLineDetail.java	Tue Apr 22 18:22:40 2014 -0700
@@ -24,7 +24,7 @@
  /*
  * @test
  * @key nmt
  * @summary Running with NMT detail should not result in an error
  * @library /testlibrary
  */
 
@@ -39,6 +39,7 @@
       "-version");
     OutputAnalyzer output = new OutputAnalyzer(pb.start());
     output.shouldNotContain("error");
+    output.shouldNotContain("warning");
     output.shouldHaveExitValue(0);
   }
 }
@@ -24,7 +24,7 @@
  * @test
  * @key nmt
- * @summary Running with NMT detail should not result in an error
+ * @summary Running with NMT detail should not result in an error or warning
  * @library /testlibrary
  */